@@ -1,4 +1,3 @@
-import networkx as nx
 import numpy as np
 
 
@@ -23,7 +22,7 @@ class CascadeWattsModel:
 
         self.no_changes = 0
         for _ag in self.__agents:
-            if self.state[_ag] == True:
+            if self.state[_ag] is True:
                 continue
             if self.network.degree(_ag) == 0:
                 continue
