@@ -1,15 +1,10 @@
 #!/usr/bin/env python3
 
 import csv
-import logging
 import optparse
-import os
 import sys
-import time
 
-import spg
 from spg.simulation import MultIteratorList
-from spg.utils import SPGSettings
 
 
 def parse_command_line():
