@@ -12,7 +12,7 @@ import spg.base as spgb
 import spg.plot as spgp
 import spg.utils as spgu
 from spg import CONFIG_DIR
-from spg.utils import evaluate_string, newline_msg
+from spg.utils import newline_msg
 
 
 class SPGPlotter:
@@ -42,7 +42,7 @@ class SPGPlotter:
 
             self.add_setting(self.x_axis, "scale = log")
             self.add_setting(
-                self.x_axis, "lim = (%s,%s)" % (x_axis_iter.xmin, x_axis_iter.xmax)
+                self.x_axis, f"lim = ({x_axis_iter.xmin},{x_axis_iter.xmax})"
             )
 
         try:
@@ -66,15 +66,13 @@ class SPGPlotter:
         repeat: how many columns are to be taken by the parser
         help: a string containing an explanation of the variable"""
 
-        possible_keys = set(
-            ["type", "label", "help", "scale", "repeat", "datatype", "lim"]
-        )
+        possible_keys = {"type", "label", "help", "scale", "repeat", "datatype", "lim"}
         ret = {}
         exec_file, ext = os.path.splitext(exec_file)
         try:
-            cfgFile = "%s.%s" % (exec_file, part)
+            cfgFile = f"{exec_file}.{part}"
         except:
-            cfgFile = "%s/%s.%s" % (CONFIG_DIR, exec_file, part)
+            cfgFile = f"{CONFIG_DIR}/{exec_file}.{part}"
         sorted_cols = []
         for line in open(cfgFile):
             if len(line.strip()) == 0:
@@ -93,9 +91,7 @@ class SPGPlotter:
                 v = v.strip()
 
                 if k not in possible_keys:
-                    newline_msg(
-                        "SYN", "in column '%s', unrecognised key '%s'" % (name, k)
-                    )
+                    newline_msg("SYN", f"in column '{name}', unrecognised key '{k}'")
                     sys.exit(1)
                 if k == "lim":
                     values[k] = eval(v)
@@ -108,9 +104,7 @@ class SPGPlotter:
 
     def add_setting(self, var, line):
 
-        possible_keys = set(
-            ["type", "label", "help", "scale", "repeat", "datatype", "lim"]
-        )
+        possible_keys = {"type", "label", "help", "scale", "repeat", "datatype", "lim"}
 
         if var not in self.settings:
             self.settings[var] = {}
@@ -123,9 +117,7 @@ class SPGPlotter:
             v = v.strip()
 
             if k not in possible_keys:
-                spgu.newline_msg(
-                    "SYN", "in column '%s', unrecognised key '%s'" % (var, k)
-                )
+                spgu.newline_msg("SYN", f"in column '{var}', unrecognised key '{k}'")
 
                 sys.exit(1)
             if k == "lim":
@@ -155,7 +147,7 @@ class SPGPlotter:
     def plot_all(self, Plotter, mean, std):
         newline_msg(
             "INF",
-            "%s - %s - %s" % (self.separated_vars, self.coalesced_vars, self.x_axis),
+            f"{self.separated_vars} - {self.coalesced_vars} - {self.x_axis}",
         )
 
         table_name = self.base_name + ".csv"
@@ -188,7 +180,7 @@ class SPGPlotter:
     def plot_all_join_outputs(self, Plotter, mean):
         newline_msg(
             "INF",
-            "%s - %s - %s" % (self.separated_vars, self.coalesced_vars, self.x_axis),
+            f"{self.separated_vars} - {self.coalesced_vars} - {self.x_axis}",
         )
 
         table_name = self.base_name + "_results.csv"
