@@ -12,7 +12,7 @@ import spg.base as spgb
 import spg.plot as spgp
 import spg.utils as spgu
 from spg import CONFIG_DIR
-from spg.utils import evaluate_string, newline_msg
+from spg.utils import newline_msg
 
 
 class SPGPlotter:
@@ -43,7 +43,7 @@ class SPGPlotter:
 
             self.add_setting(self.x_axis, "scale = log")
             self.add_setting(
-                self.x_axis, "lim = (%s,%s)" % (x_axis_iter.xmin, x_axis_iter.xmax)
+                self.x_axis, f"lim = ({x_axis_iter.xmin},{x_axis_iter.xmax})"
             )
 
         try:
@@ -67,15 +67,13 @@ class SPGPlotter:
         repeat: how many columns are to be taken by the parser
         help: a string containing an explanation of the variable"""
 
-        possible_keys = set(
-            ["type", "label", "help", "scale", "repeat", "datatype", "lim"]
-        )
+        possible_keys = {"type", "label", "help", "scale", "repeat", "datatype", "lim"}
         ret = {}
         exec_file, ext = os.path.splitext(exec_file)
         try:
-            cfgFile = "%s.%s" % (exec_file, part)
+            cfgFile = f"{exec_file}.{part}"
         except:
-            cfgFile = "%s/%s.%s" % (CONFIG_DIR, exec_file, part)
+            cfgFile = f"{CONFIG_DIR}/{exec_file}.{part}"
         sorted_cols = []
         for line in open(cfgFile):
             if len(line.strip()) == 0:
@@ -94,9 +92,7 @@ class SPGPlotter:
                 v = v.strip()
 
                 if k not in possible_keys:
-                    newline_msg(
-                        "SYN", "in column '%s', unrecognised key '%s'" % (name, k)
-                    )
+                    newline_msg("SYN", f"in column '{name}', unrecognised key '{k}'")
                     sys.exit(1)
                 if k == "lim":
                     values[k] = eval(v)
@@ -109,9 +105,7 @@ class SPGPlotter:
 
     def add_setting(self, var, line):
 
-        possible_keys = set(
-            ["type", "label", "help", "scale", "repeat", "datatype", "lim"]
-        )
+        possible_keys = {"type", "label", "help", "scale", "repeat", "datatype", "lim"}
 
         if var not in self.settings:
             self.settings[var] = {}
@@ -124,9 +118,7 @@ class SPGPlotter:
             v = v.strip()
 
             if k not in possible_keys:
-                spgu.newline_msg(
-                    "SYN", "in column '%s', unrecognised key '%s'" % (var, k)
-                )
+                spgu.newline_msg("SYN", f"in column '{var}', unrecognised key '{k}'")
 
                 sys.exit(1)
             if k == "lim":
@@ -156,10 +148,10 @@ class SPGPlotter:
     def plot_all(self, Plotter):
         newline_msg(
             "INF",
-            "%s - %s - %s" % (self.separated_vars, self.coalesced_vars, self.x_axis),
+            f"{self.separated_vars} - {self.coalesced_vars} - {self.x_axis}",
         )
 
-        table_name = "%s_%s.csv" % (self.base_name, self.table_name)
+        table_name = f"{self.base_name}_{self.table_name}.csv"
         ctp = Plotter(table_name)
 
         ctp.x_axis = self.x_axis
@@ -171,7 +163,7 @@ class SPGPlotter:
 
         ctp.settings = self.settings
 
-        plot_fname = "%s_%s_plot" % (self.base_name, self.table_name)
+        plot_fname = f"{self.base_name}_{self.table_name}_plot"
         if len(ctp.separated_vars) > 1:
             plot_fname += "_" + "_".join(ctp.separated_vars)
         if len(ctp.separated_vars) == 1:
@@ -185,10 +177,10 @@ class SPGPlotter:
     def plot_all_join_outputs(self, Plotter):
         newline_msg(
             "INF",
-            "%s - %s - %s" % (self.separated_vars, self.coalesced_vars, self.x_axis),
+            f"{self.separated_vars} - {self.coalesced_vars} - {self.x_axis}",
         )
 
-        table_name = "%s_%s.csv" % (self.base_name, self.table_name)
+        table_name = f"{self.base_name}_{self.table_name}.csv"
         ctp = Plotter(table_name)
 
         ctp.x_axis = self.x_axis
@@ -200,7 +192,7 @@ class SPGPlotter:
 
         ctp.settings = self.settings
 
-        plot_fname = "%s_%s_plot" % (self.base_name, self.table_name)
+        plot_fname = f"{self.base_name}_{self.table_name}_plot"
         if len(ctp.separated_vars) > 1:
             plot_fname += "_" + "_".join(ctp.separated_vars)
         elif len(ctp.separated_vars) == 1:
