@@ -60,7 +60,7 @@ if __name__ == "__main__":
     for i_arg in args:
         full_name, path, base_name, extension = utils.translate_name(i_arg)
 
-        db_name = "%s/%s.spgql" % (path, base_name)
+        db_name = f"{path}/{base_name}.spgql"
         # sim_name = "%s/%s.spg" % (path, base_name)
         if options.purge and os.path.exists(db_name):
             os.remove(db_name)
@@ -89,7 +89,7 @@ if __name__ == "__main__":
             if options.verbose:
                 utils.inline_msg(
                     "RUN",
-                    "[%s] %s" % (executor.current_spg_uid, executor.variable_values()),
+                    f"[{executor.current_spg_uid}] {executor.variable_values()}",
                 )
             # executor.launch_process()
             try:
