@@ -1,5 +1,4 @@
 #!/usr/bin/env python3
-# -*- coding: utf-8 -*-
 """
 Created on Mon Jul 11 11:37:27 2011
 
@@ -7,20 +6,14 @@ Created on Mon Jul 11 11:37:27 2011
 """
 
 import csv
-import fnmatch
-import math as m
-import optparse
 import os
 import os.path
 
 # from matplotlib import rc
 # import matplotlib.pyplot as plt
 # import matplotlib.pylab as plb
-import sqlite3 as sql
 import sys
 
-import numpy as np
-
 # from spg import  CONFIG_DIR
 import spg.utils as utils
 from spg.cmdline import BaseSPGCommandLine
@@ -183,7 +176,7 @@ class SPGResultsCommandLine(BaseSPGCommandLine):
                 utils.newline_msg("ERR", "only one db can be loaded at a time", 2)
                 return
 
-        if len(set(["raw", "full", "id"]).intersection(flags)) > 1:
+        if len({"raw", "full", "id"}.intersection(flags)) > 1:
             utils.newline_msg(
                 "ERR", "only one flag [raw, full, id] can be active at a time"
             )
