@@ -32,5 +32,5 @@ class ValueContainer(dict):
     def __str__(self):
         ret = ":\n"
         for k in self.keys():
-            ret += "%s = %s\n" % (k, self[k])
+            ret += f"{k} = {self[k]}\n"
         return ret
