@@ -35,7 +35,7 @@ class Iterator:
         return self
 
     def __next__(self):
-        if self.__index == None:
+        if self.__index is None:
             self.__index = 0
         else:
             self.__index += 1
@@ -122,8 +122,8 @@ class IterOperator(Iterator):
         #   do not reaches xmax
 
         assert abs(self.xmax - self.xmin) > abs(
-            self.xmax - eval("%s%s%s" % (self.xmin, it_type, self.xstep))
-        ), "on variable '%s': '%s%s%s' does not approach to %s " % (
+            self.xmax - eval(f"{self.xmin}{it_type}{self.xstep}")
+        ), "on variable '{}': '{}{}{}' does not approach to {} ".format(
             self.name,
             str(self.xmin),
             str(it_type),
@@ -138,7 +138,7 @@ class IterOperator(Iterator):
 
         while (self.xmin > self.xmax) ^ (xact <= self.xmax):  # ^ is xor in python !
             lsTmp.append(xact)
-            xact = eval("%s%s%s" % (xact, it_type, self.xstep))
+            xact = eval(f"{xact}{it_type}{self.xstep}")
 
         return lsTmp
 
@@ -180,8 +180,8 @@ class IterMutable(Iterator):
         #   do not reaches xmax
 
         assert abs(self.xmax - self.xmin) > abs(
-            self.xmax - eval("%s%s%s" % (self.xmin, it_type, self.xstep))
-        ), "on variable '%s': '%s%s%s' does not approach to %s " % (
+            self.xmax - eval(f"{self.xmin}{it_type}{self.xstep}")
+        ), "on variable '{}': '{}{}{}' does not approach to {} ".format(
             self.name,
             str(self.xmin),
             str(it_type),
@@ -207,7 +207,7 @@ class IterMutable(Iterator):
 
     def reset(self):
         self._parse()
-        super(IterMutable, self).reset()
+        super().reset()
 
 
 #:
