@@ -58,11 +58,11 @@ class MultIteratorParser(iterator.MultIterator):
         ret = ""
         for i in self.data:
             if i.__class__ == iterator.Iterator:
-                ret += ".%s  %s\n" % (i.name, " ".join(i.data))
+                ret += ".{}  {}\n".format(i.name, " ".join(i.data))
             if i.__class__ == iterator.IterConstant:
-                ret += ":%s  %s\n" % (i.name, " ".join(i.data))
+                ret += ":{}  {}\n".format(i.name, " ".join(i.data))
             if i.__class__ == iterator.IterOperator:
-                ret += "%s%s  %s  %s  %s\n" % (i.type, i.name, i.xmin, i.xmax, i.xstep)
+                ret += f"{i.type}{i.name}  {i.xmin}  {i.xmax}  {i.xstep}\n"
         return ret
 
     def fetch(self, stream):
@@ -101,7 +101,7 @@ class MultIteratorParser(iterator.MultIterator):
                         base_path == "."
                     ls_files.extend(
                         [
-                            "%s/%s" % (base_path, i)
+                            f"{base_path}/{i}"
                             for i in fnmatch.filter(os.listdir(base_path), rx)
                         ]
                     )
@@ -110,7 +110,7 @@ class MultIteratorParser(iterator.MultIterator):
             if symbol == "<":  # Reads from a regexp
                 ls_files = []
                 for rgx in rest[1:]:
-                    with open(rgx, "r") as fin:
+                    with open(rgx) as fin:
                         ls_files.extend([_.strip() for _ in fin.readlines()])
 
                 self.add(iterator.Iterator(rest[0], ls_files))
