@@ -7,10 +7,8 @@ import cmd
 import fnmatch
 import os.path
 import re
-import sys
 
 import spg.utils as utils
-from setuptools.command.saveopts import saveopts
 from spg.master import SPGMasterDB
 from spg.simulation import MultIteratorDBBuilder, ParameterEnsemble
 
@@ -48,8 +46,7 @@ class BaseSPGCommandLine(cmd.Cmd):
 
         try:
             full_name, path, base_name, extension = utils.translate_name(c.strip())
-            db_name = "%s/%s.spgql" % (path, base_name)
-            sim_name = "%s/%s.spg" % (path, base_name)
+            db_name = f"{path}/{base_name}.spgql"
         except:
             utils.newline_msg("ERR", "results db '%s' doesn't exist." % c)
             return None
@@ -66,7 +63,7 @@ class BaseSPGCommandLine(cmd.Cmd):
 
         for el in full_ls:
             full_name, path, base_name, extension = utils.translate_name(el)
-            full_base = "%s/%s" % (path, base_name)
+            full_base = f"{path}/{base_name}"
             if full_base not in ls_keys:
                 ls_res_db.add(utils.shorten_name(full_name))
                 ls_keys.add(full_base)
@@ -140,9 +137,9 @@ class SPGDBCommandLine(BaseSPGCommandLine):
         self.master_db = SPGMasterDB(EnsembleConstructor=EnsembleConstructor)
 
     def filter_db_list(self, ls=None, filter=None):
-        if ls == None:
+        if ls is None:
             ls = list(self.master_db.result_dbs.keys())
-        if re.match("^\d+?$", filter):  #:::~ Is filter an integer???
+        if re.match(r"^\d+?$", filter):  #:::~ Is filter an integer???
             id = int(filter)
             rdb = self.master_db.result_dbs
             filtered = [
@@ -208,7 +205,7 @@ class SPGDBCommandLine(BaseSPGCommandLine):
         else:
             full_name, path, base_name, extension = utils.translate_name(db_name)
             # print "do_init::: ",self.translate_name(i_arg)
-            db_name = "%s/%s.spgql" % (path, base_name)
+            db_name = f"{path}/{base_name}.spgql"
             # sim_name = "%s/%s.spg" % (path, base_name)
             if not os.path.exists(db_name):
                 utils.newline_msg(
@@ -273,8 +270,8 @@ class SPGDBCommandLine(BaseSPGCommandLine):
 
         full_name, path, base_name, extension = utils.translate_name(db_arg)
         # print "do_init::: ",self.translate_name(i_arg)
-        full_db_name = "%s/%s.spgql" % (path, base_name)
-        sim_name = "%s/%s.spg" % (path, base_name)
+        full_db_name = f"{path}/{base_name}.spgql"
+        sim_name = f"{path}/{base_name}.spg"
         if os.path.exists(full_db_name) and "purge" not in flags:
             utils.newline_msg(
                 "ERR",
@@ -418,7 +415,7 @@ class SPGDBCommandLine(BaseSPGCommandLine):
         flags, args, ensemble = self.get_flags_and_db(c)
         #   print flags, args, ensemble
 
-        if ensemble == None:
+        if ensemble is None:
             return
 
         try:
@@ -483,9 +480,7 @@ class SPGDBCommandLine(BaseSPGCommandLine):
 
         ensemble.status = st
 
-        print(
-            " +---  '%s' [status : %s ]" % (utils.shorten_name(ensemble.full_name), st)
-        )
+        print(f" +---  '{utils.shorten_name(ensemble.full_name)}' [status : {st} ]")
         self.master_db.query_master_db(
             "UPDATE dbs SET status= ? WHERE full_name = ?", st, ensemble.full_name
         )
@@ -545,7 +540,7 @@ class SPGDBCommandLine(BaseSPGCommandLine):
 
         n_repet = db_status["value_set_with_rep"] / db_status["value_set"]
 
-        print("   -+ status = %s /  weight: %5.5f " % (status, weight))
+        print(f"   -+ status = {status} /  weight: {weight:5.5f} ")
         print(
             "   -+ total  = %d*%d / done: %d (%.5f) - running: %d - error: %d "
             % (
