@@ -1,6 +1,5 @@
 # from spg import CONFIG_DIR, TIMEOUT
 
-import copy
 import os
 import os.path
 import random
@@ -115,7 +114,7 @@ class SPGMasterDB:
             "SELECT * FROM dbs WHERE full_name = ?", (param_db.full_name,)
         ).fetchone()
 
-        if res == None:
+        if res is None:
             self.cursor.execute(
                 "INSERT INTO dbs (full_name, path, base_name, total_values_set, total_combinations, done_combinations, running_combinations, error_combinations, status, weight , queue ) VALUES (?,?,?,?,?,?,?,?,?,?,?)",
                 (
