@@ -4,15 +4,10 @@ Created on 12 Apr 2014
 @author: tessonec
 """
 
-import math as m
-import os.path
 
-import numpy as np
 import pandas as pd
 import spg.base as spgb
-import spg.plot as spgp
 import spg.utils as spgu
-from spg import CONFIG_DIR
 
 # from spg.utils import newline_msg, evaluate_string, load_configuration
 
