@@ -1,16 +1,11 @@
-import datetime as dt
 import itertools
-import math as m
 
 import matplotlib as mpl
 import matplotlib.backends.backend_pdf as mpl_b_pdf
-import matplotlib.dates as mdates
 import matplotlib.lines as mlines
 import matplotlib.pyplot as plt
-import matplotlib.ticker as pltt
 import numpy as np
 import pandas as pd
-import pandas.io.parsers as pdp
 
 
 def get_available_fonts(dir_name=None):
@@ -122,13 +117,13 @@ class SPGBasePlotter:
                 )
 
             else:
-                return var.replace("$", "").replace("_", "\_")
+                return var.replace("$", "").replace("_", r"\_")
         else:
             if var in self.settings and "label" in self.settings[var]:
                 return self.settings[var]["label"].replace("\\\\", "\\")
 
             else:
-                return var.replace("_", "\_")
+                return var.replace("_", r"\_")
 
     def add_curves(self, local_df, curr_y_axis, subp, legend_prepend=""):
         if len(self.coalesced_vars) > 0:
@@ -145,12 +140,12 @@ class SPGBasePlotter:
                     minimal_gr = [minimal_gr]
                 minimal_legend = legend_prepend + ", ".join(
                     [
-                        "$%s = %s$" % (self.get_transformed_var(k), v)
+                        f"${self.get_transformed_var(k)} = {v}$"
                         for (k, v) in zip(self.coalesced_vars, minimal_gr)
                     ]
                 )
                 # print "------>",minimal_legend
-                if isinstance(curr_y_axis, type("")):
+                if isinstance(curr_y_axis, str):
                     subp.scatter(
                         minimal_df[[self.x_axis]],
                         minimal_df[[curr_y_axis]],
@@ -178,7 +173,7 @@ class SPGBasePlotter:
 
             minimal_legend = legend_prepend
 
-            if isinstance(curr_y_axis, type("")):
+            if isinstance(curr_y_axis, str):
                 subp.scatter(
                     local_df[[self.x_axis]],
                     local_df[[curr_y_axis]],
@@ -279,7 +274,7 @@ class SPGBasePlotter:
                     local_gr = [local_gr]
                 local_title = ", ".join(
                     [
-                        "$%s = %s$" % (self.get_transformed_var(k), v)
+                        f"${self.get_transformed_var(k)} = {v}$"
                         for (k, v) in zip(self.separated_vars, local_gr)
                     ]
                 )
@@ -379,7 +374,7 @@ class SPGBasePlotter:
                     local_gr = [local_gr]
                 local_title = ", ".join(
                     [
-                        "$%s = %s$" % (self.get_transformed_var(k), v)
+                        f"${self.get_transformed_var(k)} = {v}$"
                         for (k, v) in zip(self.separated_vars, local_gr)
                     ]
                 )
@@ -435,7 +430,7 @@ class SPGBasePlotter:
                 local_gr = [local_gr]
             local_title = ", ".join(
                 [
-                    "$%s = %s$" % (self.get_transformed_var(k), v)
+                    f"${self.get_transformed_var(k)} = {v}$"
                     for (k, v) in zip(self.separated_vars, local_gr)
                 ]
             )
@@ -498,7 +493,7 @@ class SPGBaseSubPlotter(SPGBasePlotter):
 
             local_title = ", ".join(
                 [
-                    "$%s = %s$" % (self.get_transformed_var(k), v)
+                    f"${self.get_transformed_var(k)} = {v}$"
                     for (k, v) in zip(self.separated_vars, local_gr)
                 ]
             )
@@ -562,7 +557,7 @@ class SPGAbstractPlotter:
             #     print self.settings[var]["label"].replace("$","").replace("\\\\",'\\')
             return self.settings[var]["label"].replace("$", "").replace("\\\\", "\\")
         else:
-            return var.replace("$", "").replace("_", "\_")
+            return var.replace("$", "").replace("_", r"\_")
 
     def add_curves(self, local_df, curr_y_axis, subp, legend_prepend=""):
 
@@ -580,12 +575,12 @@ class SPGAbstractPlotter:
                 minimal_gr = [minimal_gr]
             minimal_legend = legend_prepend + ", ".join(
                 [
-                    "$%s = %s$" % (self.get_transformed_var(k), v)
+                    f"${self.get_transformed_var(k)} = {v}$"
                     for (k, v) in zip(self.coalesced_vars, minimal_gr)
                 ]
             )
             #            print local_legend,  "------>",minimal_legend
-            if isinstance(curr_y_axis, type("")):
+            if isinstance(curr_y_axis, str):
                 subp.scatter(
                     minimal_df[[self.x_axis]],
                     minimal_df[[curr_y_axis]],
@@ -660,7 +655,7 @@ class SPGAbstractPlotter:
                     local_gr = [local_gr]
                 local_title = ", ".join(
                     [
-                        "$%s = %s$" % (self.get_transformed_var(k), v)
+                        f"${self.get_transformed_var(k)} = {v}$"
                         for (k, v) in zip(self.separated_vars, local_gr)
                     ]
                 )
@@ -760,7 +755,7 @@ class SPGAbstractPlotter:
                     local_gr = [local_gr]
                 local_title = ", ".join(
                     [
-                        "$%s = %s$" % (self.get_transformed_var(k), v)
+                        f"${self.get_transformed_var(k)} = {v}$"
                         for (k, v) in zip(self.separated_vars, local_gr)
                     ]
                 )
@@ -816,7 +811,7 @@ class SPGAbstractPlotter:
                 local_gr = [local_gr]
             local_title = ", ".join(
                 [
-                    "$%s = %s$" % (self.get_transformed_var(k), v)
+                    f"${self.get_transformed_var(k)} = {v}$"
                     for (k, v) in zip(self.separated_vars, local_gr)
                 ]
             )
