@@ -7,7 +7,6 @@ Created on 12 Apr 2014
 """
 
 import itertools
-import math as m
 import os.path
 import re
 
@@ -21,7 +20,6 @@ import spg.base as spgb
 import spg.plot as spgp
 import spg.utils as spgu
 from IPython.display import display
-from spg import CONFIG_DIR
 from spg.plot import DataFrameIterator
 
 # from spg.utils import newline_msg, evaluate_string, load_configuration
@@ -411,8 +409,8 @@ class SPGInteractivePlotter:
     def redraw(self):
 
         mpl.rcParams["text.usetex"] = "false"
-        color_it = itertools.cycle(self.colors)
-        marker_it = itertools.cycle(self.markers)
+        itertools.cycle(self.colors)
+        itertools.cycle(self.markers)
 
         for ix, iv in enumerate(self.coalesced_values):
             query_inn_str = " & ".join(
@@ -750,8 +748,8 @@ class SPGInteractiveScalingPlotter:
         self.data_transformed["transformed_y"] = self.evaluate_string(self.y_transform)
 
     def redraw(self):
-        color_it = itertools.cycle(self.colors)
-        marker_it = itertools.cycle(self.markers)
+        itertools.cycle(self.colors)
+        itertools.cycle(self.markers)
 
         for ix, iv in enumerate(self.coalesced_values):
             query_inn_str = " & ".join(
