@@ -1,5 +1,4 @@
-import sqlite3 as sql
-from subprocess import PIPE, Popen
+from subprocess import Popen
 
 from spg import BINARY_PATH
 
