@@ -35,7 +35,7 @@ class SingleRunner:
         if workers in {0, 1}:
             self.results = [run_simulation(el) for el in tqdm(self.parameters)]
         elif (
-            workers == None
+            workers is None
         ):  # number of workers is not setup, so all resources are taken
             with concurrent.futures.ProcessPoolExecutor() as executor:
                 self.results = list(
