@@ -29,7 +29,7 @@ class ParameterEnsemble:
         self.full_name, self.path, self.base_name, ext = utils.translate_name(full_name)
 
         self.db_name = "%s.spgql" % self.base_name
-        self.full_name = "%s/%s.spgql" % (self.path, self.base_name)
+        self.full_name = f"{self.path}/{self.base_name}.spgql"
         self.id = id
         self.values = {}
         # self.directory_vars = None
@@ -72,9 +72,9 @@ class ParameterEnsemble:
         try:
             ret = [i for i in self.cursor.execute(query, args)]
         except:
-            utils.newline_msg("ERR QUERY", "%s - %s" % (query, args))
+            utils.newline_msg("ERR QUERY", f"{query} - {args}")
             flog = open("query_error.log", "wa")
-            utils.newline_msg("ERR QUERY", "%s - %s" % (query, args), stream=flog)
+            utils.newline_msg("ERR QUERY", f"{query} - {args}", stream=flog)
             flog.close()
         self.__close_db()
         return ret
@@ -157,7 +157,7 @@ class ParameterEnsemble:
         # self.directory_vars = self.variables[:-1]
 
     def query_set_run_status(self, status, id=None, run_time=None):
-        if id == None:
+        if id is None:
             id = self.current_spg_uid
         if run_time:
             self.execute_query(
@@ -180,7 +180,7 @@ class ParameterEnsemble:
             + "WHERE r.status = 'N' AND v.id = r.spg_vsid ORDER BY r.id LIMIT 1"
         )
         res = self.execute_query_fetchone(query)
-        if res == None:
+        if res is None:
             raise StopIteration
 
         # print res, self.entities
@@ -302,12 +302,12 @@ class ParameterEnsembleExecutor(ParameterEnsemble):
             print(k, utils.replace_values(self.values[k], self), file=fconf)
         fconf.close()
 
-        fname_stdout = "%s_%s.tmp_stdout" % (self.base_name, self.current_spg_uid)
-        fname_stderr = "%s_%s.tmp_stderr" % (self.base_name, self.current_spg_uid)
+        fname_stdout = f"{self.base_name}_{self.current_spg_uid}.tmp_stdout"
+        fname_stderr = f"{self.base_name}_{self.current_spg_uid}.tmp_stderr"
         file_stdout = open(fname_stdout, "w")
         file_stderr = open(fname_stderr, "w")
 
-        cmd = "%s/%s %s" % (self.bin_dir, self.command, configuration_filename)
+        cmd = f"{self.bin_dir}/{self.command} {configuration_filename}"
 
         started_time = time.time()
         proc = Popen(
@@ -325,9 +325,9 @@ class ParameterEnsembleExecutor(ParameterEnsemble):
         file_stdout.close()
         file_stderr.close()
 
-        self.output = [i.strip() for i in open(fname_stdout, "r")]
+        self.output = [i.strip() for i in open(fname_stdout)]
         # print("OUT <<< ", self.output)
-        self.stderr = [i.strip() for i in open(fname_stderr, "r")]
+        self.stderr = [i.strip() for i in open(fname_stderr)]
         if remove_files:
             os.remove(configuration_filename)
             os.remove(fname_stdout)
@@ -365,7 +365,7 @@ class ParameterEnsembleExecutor(ParameterEnsemble):
             ] + output_columns
             #            print(self.table_columns[table_name],["'%s'" % str(i) for i in output_columns])
 
-            cc = "INSERT INTO %s (%s) VALUES (%s) " % (
+            cc = "INSERT INTO {} ({}) VALUES ({}) ".format(
                 table_name,
                 ", ".join(self.table_columns[table_name]),
                 ", ".join(["'%s'" % str(i) for i in output_columns]),
@@ -446,13 +446,13 @@ class ParameterEnsembleThreaded(ParameterEnsemble):
             print(k, utils.replace_values(values[k], self), file=fconf)
         fconf.close()
 
-        fname_stdout = "%s_%s.tmp_stdout" % (self.base_name, current_run_id)
-        fname_stderr = "%s_%s.tmp_stderr" % (self.base_name, current_run_id)
+        fname_stdout = f"{self.base_name}_{current_run_id}.tmp_stdout"
+        fname_stderr = f"{self.base_name}_{current_run_id}.tmp_stderr"
         file_stdout = open(fname_stdout, "w")
         file_stderr = open(fname_stderr, "w")
 
         started_time = time.time()
-        cmd = "%s/%s  %s" % (self.bin_dir, self.command, configuration_filename)
+        cmd = f"{self.bin_dir}/{self.command}  {configuration_filename}"
 
         proc = Popen(
             cmd,
@@ -469,22 +469,18 @@ class ParameterEnsembleThreaded(ParameterEnsemble):
         file_stdout.close()
         file_stderr.close()
 
-        output = [i.strip() for i in open(fname_stdout, "r")]
-        stderr = [i.strip() for i in open(fname_stderr, "r")]
+        output = [i.strip() for i in open(fname_stdout)]
+        stderr = [i.strip() for i in open(fname_stderr)]
 
         if self.test_run:
             if not os.path.exists("configuration-%s" % self.base_name):
                 os.mkdir("configuration-%s" % self.base_name)
             os.rename(
                 configuration_filename,
-                "configuration-%s/%s" % (self.base_name, configuration_filename),
-            )
-            os.rename(
-                fname_stdout, "configuration-%s/%s" % (self.base_name, fname_stdout)
-            )
-            os.rename(
-                fname_stderr, "configuration-%s/%s" % (self.base_name, fname_stderr)
+                f"configuration-{self.base_name}/{configuration_filename}",
             )
+            os.rename(fname_stdout, f"configuration-{self.base_name}/{fname_stdout}")
+            os.rename(fname_stderr, f"configuration-{self.base_name}/{fname_stderr}")
 
         else:
             os.remove(configuration_filename)
@@ -530,7 +526,7 @@ class ParameterEnsembleThreaded(ParameterEnsemble):
             table_name, output_columns = self.parse_output_line(line)
 
             output_columns = [current_uid, current_vsid, current_rep] + output_columns
-            cc = "INSERT INTO %s (%s) VALUES (%s) " % (
+            cc = "INSERT INTO {} ({}) VALUES ({}) ".format(
                 table_name,
                 ", ".join(self.table_columns[table_name]),
                 ", ".join(["'%s'" % str(i) for i in output_columns]),
@@ -798,11 +794,11 @@ class ResultsDBQuery(ParameterEnsemble):
             self.clean_dict(restrict_to_values)
             restrict_to_values_query = " AND ".join(
                 [
-                    "v.%s = '%s'" % (v, restrict_to_values[v])
+                    f"v.{v} = '{restrict_to_values[v]}'"
                     for v in list(restrict_to_values.keys())
                 ]
             )
-            query = "%s AND %s " % (query, restrict_to_values_query)
+            query = f"{query} AND {restrict_to_values_query} "
 
         if table_selector == "grouped_vars":
             query = "%s GROUP BY v.id" % (query)
@@ -847,9 +843,9 @@ class ResultsDBQuery(ParameterEnsemble):
             (vsid, rep) = self.execute_query_fetchone(
                 "SELECT spg_vsid, spg_rep FROM run_status WHERE id = %s" % uid
             )
-            vals = row[1:]
+            row[1:]
             full_row = [uid, vsid, rep] + row[1:]
-            cc = "INSERT INTO %s (%s) VALUES (%s) " % (
+            cc = "INSERT INTO {} ({}) VALUES ({}) ".format(
                 table_name,
                 ", ".join(header),
                 ", ".join(["'%s'" % str(i) for i in full_row]),
