@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 """
 Created on Mon Jul 11 11:23:41 2011
 
@@ -7,11 +6,8 @@ Created on Mon Jul 11 11:23:41 2011
 Implementation of the paramaters.dat in the form of a database
 """
 
-import csv
-import os.path
 import sqlite3 as sql
 import sys
-from collections import namedtuple
 
 from .. import database_version, utils
 from ..base import IterConstant, MultIteratorParser
@@ -36,7 +32,7 @@ class SPGConflictingValue(Exception):
 
         utils.newline_msg(
             "ERR",
-            "conflict in %s name (in db '%s', in param '%s')" % (key, previous, value),
+            f"conflict in {key} name (in db '{previous}', in param '{value}')",
         )
 
 
@@ -46,8 +42,8 @@ class MultIteratorDBBuilder(MultIteratorParser):
     def __init__(self, db_name, timeout=5):
         full_name, self.path, self.base_name, extension = utils.translate_name(db_name)
 
-        self.db_name = "%s/%s.spgql" % (self.path, self.base_name)
-        sim_name = "%s/%s.spg" % (self.path, self.base_name)
+        self.db_name = f"{self.path}/{self.base_name}.spgql"
+        sim_name = f"{self.path}/{self.base_name}.spg"
 
         MultIteratorParser.__init__(self, open(sim_name))
         #   print self.data
@@ -120,13 +116,11 @@ class MultIteratorDBBuilder(MultIteratorParser):
                 )
         else:
             self.cursor.execute("SELECT name FROM entities ")
-            entities = set([i[0] for i in self.cursor])
+            entities = {i[0] for i in self.cursor}
             s_names = set(self.names)
 
             if entities != set(self.names):
-                utils.newline_msg(
-                    "ERR", "parameter (was %s, is %s)" % (entities, s_names)
-                )
+                utils.newline_msg("ERR", f"parameter (was {entities}, is {s_names})")
                 sys.exit(1)
 
         self.connection.commit()
@@ -138,7 +132,7 @@ class MultIteratorDBBuilder(MultIteratorParser):
         # print elements
         self.cursor.execute(elements)
 
-        elements = "INSERT INTO values_set ( %s ) VALUES (%s)" % (
+        elements = "INSERT INTO values_set ( {} ) VALUES ({})".format(
             ", ".join(["%s " % i for i in self.names]),
             ", ".join("?" for i in self.names),
         )
@@ -162,7 +156,7 @@ class MultIteratorDBBuilder(MultIteratorParser):
                     utils.replace_values(
                         self[j],
                         self,
-                        vars_to_skip=set(["spg_uid", "spg_vsid", "spg_rep"]),
+                        vars_to_skip={"spg_uid", "spg_vsid", "spg_rep"},
                     )
                     for j in self.names
                 ],
@@ -188,7 +182,10 @@ class MultIteratorDBBuilder(MultIteratorParser):
                 % (
                     results_table,
                     ", ".join(
-                        ["%s %s" % (ic, iv["datatype"]) for ic, iv in table_contents]
+                        [
+                            "{} {}".format(ic, iv["datatype"])
+                            for ic, iv in table_contents
+                        ]
                     ),
                 )
             )
