@@ -1,10 +1,7 @@
 #!/usr/bin/env python3
-# -*- coding: utf-8 -*-
 
 import copy
-import optparse
 import os.path
-import sys
 
 from .load_configs import *
 from .tools import evaluate_string, newline_msg
@@ -70,24 +67,22 @@ def consistency(exec_file, miparser):
                 consistent_param = False
             elif pc.var_type == "str":
                 try:
-                    str("%s(%s)" % (pc.var_type, evaluate_string(val, miparser)))
+                    str(f"{pc.var_type}({evaluate_string(val, miparser)})")
                 except:
                     newline_msg(
                         "VAL",
-                        "wrong type for '%s' expected '%s' " % (it.name, pc.var_type),
+                        f"wrong type for '{it.name}' expected '{pc.var_type}' ",
                     )
                     consistent_param = False
 
-            elif pc.var_type in set(
-                ["float", "int", "bool"]
-            ):  # in set(["float","double"]):
+            elif pc.var_type in {"float", "int", "bool"}:  # in set(["float","double"]):
                 #    print it.name, var_type, val, evaluate_string(val, miparser)
                 try:
-                    eval("%s(%s)" % (pc.var_type, evaluate_string(val, miparser)))
+                    eval(f"{pc.var_type}({evaluate_string(val, miparser)})")
                 except:
                     newline_msg(
                         "VAL",
-                        "wrong type for '%s' expected '%s' " % (it.name, pc.var_type),
+                        f"wrong type for '{it.name}' expected '{pc.var_type}' ",
                     )
                     consistent_param = False
 
