@@ -1,5 +1,4 @@
 #!/usr/bin/env python3
-# -*- coding: utf-8 -*-
 
 import os.path
 import re
@@ -27,9 +26,7 @@ def str_color(s):
 def generate_string(values, var_list, separator="-", joining_string="_"):
     """Replaces a list of variables with its value into a string"""
 
-    thisstr = joining_string.join(
-        ["%s%s%s" % (k, separator, values[k]) for k in var_list if k]
-    )
+    thisstr = joining_string.join([f"{k}{separator}{values[k]}" for k in var_list if k])
 
     return fix_filename(thisstr)
 
@@ -136,9 +133,7 @@ def replace_values(string, val_dict, vars_to_skip=set()):
     for i_var in rx_c.findall(string):
         if i_var in vars_to_skip:
             continue
-        st_out = re.sub(
-            r"\{%s\}" % i_var, "%s-%s" % (i_var, str(val_dict[i_var])), st_out
-        )
+        st_out = re.sub(r"\{%s\}" % i_var, f"{i_var}-{str(val_dict[i_var])}", st_out)
 
     try:
         ret = eval(st_out)
